# is-relative [![NPM version](https://badge.fury.io/js/is-relative.svg)](http://badge.fury.io/js/is-relative)

> Returns `true` if the path appears to be relative.

## Install
### Install with [npm](npmjs.org)

```bash
npm i is-relative --save
```

## Usage
### [isRelative](index.js#L16)

* `filepath` **{String}**: Path to test.    
* `returns`: {Boolean}  

```js
var isRelative = require('is-relative');
isRelative('README.md');
//=> true
```


## Author

**Jon Schlinkert**
 
+ [github/jonschlinkert](https://github.com/jonschlinkert)
+ [twitter/jonschlinkert](http://twitter.com/jonschlinkert) 

## License
Copyright (c) 2014 Jon Schlinkert  
Released under the MIT license

***

_This file was generated by [verb](https://github.com/assemble/verb) on November 17, 2014._